@@ -93,12 +93,8 @@ g_strreplace (gchar * string, gchar * search, gchar * replace)
 void
 save_info(GtkWidget *wid, gpointer user_data)
 {
-	GtkIconTheme	*it;
-        GtkIconInfo	*info;
         GConfClient* client;
         int i;
-        
-        it = gtk_icon_theme_new();
        	client = GCONF_CLIENT(user_data);
 	GSList  *lst = NULL;
 	GError  *error;
@@ -106,13 +102,14 @@ save_info(GtkWidget *wid, gpointer user_data)
         for(i=0;i<4;i++) {
 		        
 		if ( names[i] != NULL ) lst = g_slist_append (lst, names[i]);
-		if ( icons[i] != NULL ) {
-		info = gtk_icon_theme_lookup_icon (it, g_strdup_printf(icons[i]), 64, 0);
-		if (info)
-			icons[i] = g_strdup (gtk_icon_info_get_filename (info));
+		if ( icons[i] != NULL ) lst = g_slist_append (lst, icons[i]);
+		/*{
+			info = gtk_icon_theme_lookup_icon (it, g_strdup_printf(icons[i]), 64, 0);
+			if (info)
+				icons[i] = g_strdup (gtk_icon_info_get_filename (info));
 		
-		lst = g_slist_append (lst, icons[i]);
-		}
+			lst = g_slist_append (lst, icons[i]);
+		}*/
 		if ( ossos[i] != NULL ) lst = g_slist_append (lst, ossos[i]);
 		if ( bins[i] != NULL ) lst = g_slist_append (lst, bins[i]);        
 
@@ -151,7 +148,12 @@ parse_settings(GConfClient* client)
 	GSList *lst = NULL;
 	gpointer *nm,*in,*o,*b;
 	GdkPixbuf *pixim;
+        GtkIconTheme	*it;
+        GtkIconInfo	*info;
+        gchar *iname;
+
 	
+	it = gtk_icon_theme_get_default();
 	for(i=0;i<4;i++) {
 		if (gconf_entry_get_value (g_strdup_printf("%s%s",APP_GCONF_KEY,group_name[i])) != NULL) {
 			lst = gconf_client_get_list (GCONF_CLIENT(client),g_strdup_printf("%s%s",APP_GCONF_KEY,group_name[i]), GCONF_VALUE_STRING, &err);
@@ -164,8 +166,12 @@ parse_settings(GConfClient* client)
 				icons[i] = (gchar *)in;
 				ossos[i] = (gchar *)o;
 				bins[i] = (gchar *)b;
-				if ( g_strcmp0(in,"") != 0 ) {
-					pixim = gdk_pixbuf_new_from_file ( (gchar *)in, NULL );
+				if ( g_strcmp0(icons[i],"") != 0 ) {
+					info = gtk_icon_theme_lookup_icon (it, icons[i], 64, 0);
+					if (info)
+						iname = g_strdup (gtk_icon_info_get_filename (info));
+						
+					pixim = gdk_pixbuf_new_from_file ( iname, NULL );
 					icoim = gtk_image_new_from_pixbuf (gdk_pixbuf_scale_simple ( pixim, 48,48, GDK_INTERP_BILINEAR ));
 				
 					hildon_button_set_image ( HILDON_BUTTON(btns[i]), icoim );
