@@ -36,25 +36,39 @@ HD_DEFINE_PLUGIN_MODULE (QuickLaunchStatusMenuItem, quick_launch_status_menu_ite
 void
 parse_info (GConfClient* client, gboolean big_icon)
 {
-	g_print("parsing info\n");
+	FILE *f;
+	f = fopen("/tmp/qldtmp", "a");
+	fprintf(f,"parsing info\n");
 	if ( client == NULL )
-		g_print("clnt null\n");
-	else g_print("clnt ok'\n");
+		fprintf(f,"clnt null\n");
+	else fprintf(f,"clnt ok'\n");
 	GError *err;
 	GtkWidget *icoim;
 	GdkPixbuf *pixim;
+	GtkIconTheme	*it;
+        GtkIconInfo	*info;
 	int i;
 	GSList *lst = NULL;
 	gpointer *in;
+	gchar *iname;
 	
+	it = gtk_icon_theme_get_default();
+	if ( it == NULL ) 
+		fprintf(f,"icon theme null!\n");
+	else fprintf(f,"icon theme ok\n");
 	for(i=0;i<4;i++) {
 		if (gconf_entry_get_value (g_strdup_printf("%s%s",APP_GCONF_KEY,group_name[i])) != NULL) {
 			lst = gconf_client_get_list (GCONF_CLIENT(client),g_strdup_printf("%s%s",APP_GCONF_KEY,group_name[i]), GCONF_VALUE_STRING, &err);
 			if ( lst != NULL ) {
 				in = g_slist_nth_data (lst, 1);
 				
-				g_print("getted = %s\n",in);
-				pixim = gdk_pixbuf_new_from_file ( (gchar *)in, NULL );
+				fprintf(f,"lookup %s\n",(gchar *)in);
+				info = gtk_icon_theme_lookup_icon (it, (gchar *)in/*g_strdup_printf(icons[i])*/, 64, 0);
+				if (info)
+					iname = g_strdup (gtk_icon_info_get_filename (info));
+
+				fprintf(f,"getted = %s\n",iname);
+				pixim = gdk_pixbuf_new_from_file ( iname, NULL );
 				if ( big_icon )
 					icoim = gtk_image_new_from_pixbuf (gdk_pixbuf_scale_simple (pixim, 64,64, GDK_INTERP_BILINEAR) );
 				else 
@@ -69,7 +83,7 @@ parse_info (GConfClient* client, gboolean big_icon)
 			}
 		}
 	}
-	
+	fclose(f);
 }
 
 
